==> lucene-core-5.0-20140814.093219-566-sources.jar: org/apache/lucene/search/FilterLeafCollector.java <==
package org.apache.lucene.search;

/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import java.io.IOException;

/**
 * {@link LeafCollector} delegator.
 *
 * @lucene.experimental
 */
public class FilterLeafCollector implements LeafCollector {

  protected final LeafCollector in;

  /** Sole constructor. */
  public FilterLeafCollector(LeafCollector in) {
    this.in = in;
  }

  @Override
  public void setScorer(Scorer scorer) throws IOException {
    in.setScorer(scorer);
  }

  @Override
  public void collect(int doc) throws IOException {
    in.collect(doc);
  }

  @Override
  public boolean acceptsDocsOutOfOrder() {
    return in.acceptsDocsOutOfOrder();
  }

  @Override
  public String toString() {
    return getClass().getSimpleName() + "(" + in + ")";
  }

}

==> lucene-core-5.5.4-sources.jar: org/apache/lucene/search/FilterLeafCollector.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.lucene.search;


import java.io.IOException;

/**
 * {@link LeafCollector} delegator.
 *
 * @lucene.experimental
 */
public class FilterLeafCollector implements LeafCollector {

  protected final LeafCollector in;

  /** Sole constructor. */
  public FilterLeafCollector(LeafCollector in) {
    this.in = in;
  }

  @Override
  public void setScorer(Scorer scorer) throws IOException {
    in.setScorer(scorer);
  }

  @Override
  public void collect(int doc) throws IOException {
    in.collect(doc);
  }

  @Override
  public String toString() {
    String name = getClass().getSimpleName();
    if (name.length() == 0) {
      // an anonoymous subclass will have empty name?
      name = "FilterLeafCollector";
    }
    return name + "(" + in + ")";
  }

}
